@@ -317,10 +317,7 @@ def addResource(apiInstance, appInstance):
 
 def initialize(apiInstance, appInstance) :
     log.success(initialize, 'SessionManager is running')
-
-def afterHttpRequest(apiInstance, appInstance):
-    ...
-
+    
 def onShutdown(apiInstance, appInstance) :
     @appInstance.teardown_appcontext
     def closeSessionManager(error):
